Internal session state used to store API keys for web services.
A named list of character strings.
Users can set API keys with setAPIKey(). Keys are remembered for the
duration of the R session and can be retrieved with getAPIKey().
This provides a small abstraction layer for dependent packages so that data access functions can test for and retrieve provider-specific API keys with generic code.