Determine whether logger.setup() has already been called.

logger.isInitialized()

Value

Logical scalar indicating whether logging has been initialized.

Details

This function is useful in package code that conditionally emits log statements only when logging has been configured.

See also

Examples

if (FALSE) { # \dontrun{
logger.isInitialized()

logger.setup()

logger.isInitialized()
} # }