Set the minimum log level displayed in the console.
logger.setLevel(level)No return value. Called for side effects.
By default, only FATAL messages are displayed in the console. This
function allows users to display additional log messages interactively.
Only the console threshold is changed. Messages written to log files by
logger.setup() or initializeLogging() are controlled by each file's own
fixed level (for example, INFO.log always receives INFO and higher
messages) and are not affected.
Available log levels are:
TRACE
DEBUG
INFO
WARN
ERROR
FATALAll functionality is implemented with the excellent logger package.
if (FALSE) { # \dontrun{
# Enable console logging
logger.setup()
# Show DEBUG and higher messages in the console
logger.setLevel(DEBUG)
} # }