Create a standard set of MazamaCoreUtils log files.

initializeLogging(logDir = NULL, filePrefix = "", createDir = TRUE)

Arguments

logDir

Directory in which to write log files.

filePrefix

Character string prepended to log file names.

createDir

Logical specifying whether to create logDir if it does not already exist.

Value

No return value. Called for side effects.

Details

This convenience function creates or validates a log directory, archives any existing standard log files by appending a UTC timestamp, and then initializes logging with logger.setup().

Standard log files include:


TRACE.log
DEBUG.log
INFO.log
WARN.log
ERROR.log

When filePrefix is supplied, it is prepended to each log file name.

See also