Create a standard set of MazamaCoreUtils log files.
initializeLogging(logDir = NULL, filePrefix = "", createDir = TRUE)No return value. Called for side effects.
This convenience function creates or validates a log directory, archives any
existing standard log files by appending a UTC timestamp, and then initializes
logging with logger.setup().
Standard log files include:
TRACE.log
DEBUG.log
INFO.log
WARN.log
ERROR.logWhen filePrefix is supplied, it is prepended to each log file name.