Learn R Programming

MazamaCoreUtils (version 0.6.2)

logger.isInitialized: Check whether logging has been initialized

Description

Determine whether logger.setup() has already been called.

Usage

logger.isInitialized()

Arguments

Value

Logical scalar indicating whether logging has been initialized.

Details

This function is useful in package code that conditionally emits log statements only when logging has been configured.

See Also

logger.setup()

Examples

Run this code
if (FALSE) {
logger.isInitialized()

logger.setup()

logger.isInitialized()
}

Run the code above in your browser using DataLab