powered by
Determine whether logger.setup() has already been called.
logger.setup()
logger.isInitialized()
Logical scalar indicating whether logging has been initialized.
This function is useful in package code that conditionally emits log statements only when logging has been configured.
if (FALSE) { logger.isInitialized() logger.setup() logger.isInitialized() }
Run the code above in your browser using DataLab