Set the minimum log level displayed in the console.

logger.setLevel(level)

Arguments

level

Logging threshold level.

Value

No return value. Called for side effects.

Details

By default, only FATAL messages are displayed in the console. This function allows users to display additional log messages interactively.

Available log levels are:


TRACE
DEBUG
INFO
WARN
ERROR
FATAL

Note

All functionality is implemented with the excellent logger package.

See also

Examples

if (FALSE) { # \dontrun{
# Enable console logging
logger.setup()

# Show DEBUG and higher messages in the console
logger.setLevel(DEBUG)
} # }