Set the minimum log level displayed in the console.
logger.setLevel(level)No return value. Called for side effects.
By default, only FATAL messages are displayed in the console. This
function allows users to display additional log messages interactively.
Available log levels are:
TRACE
DEBUG
INFO
WARN
ERROR
FATALAll functionality is implemented with the excellent logger package.
if (FALSE) { # \dontrun{
# Enable console logging
logger.setup()
# Show DEBUG and higher messages in the console
logger.setLevel(DEBUG)
} # }