powered by
Set the minimum log level displayed in the console.
logger.setLevel(level)
No return value. Called for side effects.
Logging threshold level.
By default, only FATAL messages are displayed in the console. This function allows users to display additional log messages interactively.
FATAL
Available log levels are:
TRACE DEBUG INFO WARN ERROR FATAL
logger.setup()
if (FALSE) { # Enable console logging logger.setup() # Show DEBUG and higher messages in the console logger.setLevel(DEBUG) }
Run the code above in your browser using DataLab