Convenience wrappers around devtools::check() for package checking at
different levels of thoroughness.
check(pkg = ".")check_fast(pkg = ".")
check_faster(pkg = ".")
check_fastest(pkg = ".")
check_slow(pkg = ".")
check_slower(pkg = ".")
check_slowest(pkg = ".")
Invisibly returns the result from devtools::check().
Package location passed to devtools::check().
These functions make it easy to run quick checks during active development and more thorough checks before merging or releasing package changes.
The functions are ordered from most thorough to fastest:
check_slowest()Builds the manual, runs donttest and dontrun examples, and
uses --use-gct.
check_slower()Builds the manual and runs donttest and dontrun examples.
check_slow()Builds the manual and runs donttest examples.
check()Standard development check without building the manual or running
donttest examples.
check_fast()Skips vignette building and ignores vignettes during checking.
check_faster()Skips vignette building, ignores vignettes, and skips examples.
check_fastest()Skips vignette building, ignores vignettes, skips examples, and skips tests.