Set the API key associated with a web service provider.

setAPIKey(provider = NULL, key = NULL)

Arguments

provider

Web service provider.

key

API key.

Value

Invisibly returns the previous value of the API key.

Details

API keys are stored in package session state and are remembered only for the duration of the current R session.