Learn R Programming

MazamaCoreUtils (version 0.6.2)

setAPIKey: Set API key

Description

Set the API key associated with a web service provider.

Usage

setAPIKey(provider = NULL, key = NULL)

Value

Invisibly returns the previous value of the API key.

Arguments

provider

Web service provider.

key

API key.

Details

API keys are stored in package session state and are remembered only for the duration of the current R session.

See Also

getAPIKey(), showAPIKeys()