Learn R Programming

MazamaCoreUtils (version 0.6.2)

timezoneLintRules: Timezone linting rules

Description

Rules used by lintFunctionArgs_file() and lintFunctionArgs_dir() to find date/time function calls that should explicitly specify timezone arguments.

Usage

timezoneLintRules

Arguments

Format

A named list of function/argument pairs.

Details

Each list name is a function to check. Each value is the required named timezone-related argument for that function.

Entries with "DEPRECATED" are used to flag functions that should generally be avoided in package code because they depend on the local system clock or timezone.

Examples

Run this code
str(timezoneLintRules)

Run the code above in your browser using DataLab